| Plastic | R Documentation |
An experiment was conducted to determine the optimal conditions for
extruding plastic film. Three responses were measured in relation to two
factors, change in rate of extrusion and amount of an additive, both with two levels and n=5 observations per cell.
A data frame with 20 observations on the following 5 variables.
teara numeric vector: tear resistance
glossa numeric vector: film gloss
opacitya numeric vector: film opacity
ratea factor representing change in the rate of extrusion with levels Low (-10%), High (10%)
additivea factor with levels Low (1.0%), High (1.5%)
Johnson, R.A. & Wichern, D.W. (1992). Applied Multivariate Statistical Analysis, 3rd ed., Prentice-Hall. Example 6.12 (p. 266).
Krzanowski, W. J. (1988). Principles of Multivariate Analysis. A User's Perspective. Oxford. (p. 381)
str(Plastic)
plastic.mod <- lm(cbind(tear, gloss, opacity) ~ rate*additive, data=Plastic)
car::Anova(plastic.mod)
pairs(plastic.mod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.