Learn R Programming

heplots (version 1.8.5)

Mahalanobis: Classical and Robust Mahalanobis Distances

Description

This function is a convenience wrapper to stats::mahalanobis() offering also the possibility to calculate robust Mahalanobis squared distances using MCD and MVE estimators of center and covariance (from MASS::cov.rob())

Usage

Mahalanobis(
  x,
  center,
  cov,
  method = c("classical", "mcd", "mve"),
  nsamp = "best",
  ...
)

Value

 a vector of length `nrow(x)` containing the squared distances.

Arguments

x

a numeric matrix or data frame with, say, \(p\) columns

center

mean vector of the data; if this and cov are both supplied, the function simply calls stats::mahalanobis() to calculate the result

cov

covariance matrix (p x p) of the data

method

estimation method used for center and covariance, one of: "classical" (product-moment), "mcd" (minimum covariance determinant), or "mve" (minimum volume ellipsoid).

nsamp

passed to MASS::cov.rob()

...

other arguments passed to MASS::cov.rob()

Author

Michael Friendly

Details

Any missing data in a row of x causes NA to be returned for that row.

See Also

stats::mahalanobis(), MASS::cov.rob()

Other robust methods: plot.robmlm(), robmlm()

Examples

Run this code

summary(Mahalanobis(iris[, 1:4]))
summary(Mahalanobis(iris[, 1:4], method="mve"))
summary(Mahalanobis(iris[, 1:4], method="mcd"))


Run the code above in your browser using DataLab