powered by
Draws a 3D arrow in an rgl scene with barbs at the arrow head
arrow3d( p0 = c(0, 0, 0), p1 = c(1, 1, 1), barblen, s = 0.05, theta = pi/6, n = 3, ... )
Returns (invisibly): integer ID of the line added to the scene %%
Initial point (tail of arrow)
Ending point (head of arrow)
Length of each barb, in data units
length of barb as fraction of line length (unless barblen is specified)
opening angle of barbs
number of barbs
args passed to lines3d for line styling, e.g., color, lwd, etc. See rgl::material3d().
color
lwd
rgl::material3d()
Barry Rowlingson, posted to R-help, 1/10/2010
rgl::lines3d(), rgl::segments3d(),
rgl::lines3d()
rgl::segments3d()
Other 3D plotting: bbox3d(), cross3d(), ellipse3d.axes(), heplot3d()
bbox3d()
cross3d()
ellipse3d.axes()
heplot3d()
arrow3d(c(0,0,0), c(2,2,2), barblen=.2, lwd=3, col="black") arrow3d(c(0,0,0), c(-2,2,2), barblen=.2, lwd=3, col="red")
Run the code above in your browser using DataLab