This function takes an "mlm" object, fit by stats::lm() with a multivariate response.
The goal is to return something analogous to broom::glance.lm() for a univariate response linear model.
Usage
# S3 method for mlm
glance(x, ...)
Value
A tibble::tibble() with one row for each response variable and the columns:
r.squared
R squared statistic, or the percent of variation explained by the model.
sigma
Estimated standard error of the residuals
fstatitic
Overall F statistic for the model
numdf
Numerator degrees of freedom for the overall test
dendf
Denominator degrees of freedom for the overall test
p.value
P-value corresponding to the F statistic
nobs
Number of observations used
Arguments
x
An "mlm" object created by stats::lm(), i.e., with a multivariate response.
...
Additional arguments. Not used.
Details
In the multivariate case, it returns a tibble::tibble() with one row for each
response variable, containing goodness of fit measures, F-tests and p-values.
See Also
Other multivariate linear models:
coefplot(),
stdcoef(),
stdmodel()