mlm method for the generic
pairs function) constructs a ``matrix'' of pairwise
HE plots (see heplot) for a multivariate linear model.## S3 method for class 'mlm':
pairs(x, variables, var.labels, var.cex=2,
type = c("II", "III", "2", "3"),
idata=NULL, idesign=NULL, icontrasts=NULL, imatrix=NULL, iterm=NULL, manova,
offset.axes = 0.05, digits = getOption("digits") - 1, fill=FALSE, fill.alpha=0.3, ...)mlm."II", "III", "2", or "3", where "II" is
the default (and "2" is a synomym).Anova for an explanation of the intra-subject design aidata and idesign, you can specify the
intra-subject design matrix directly via imatrix, in the form of list of named elements.
Each element gives
the columns of the within-subject model matriterm effect as well as all interactions
of Anova.mlm object for the model; if absent a
MANOVA is computed. Specifying the argument can therefore save
computation in repeated calls."digits" option.[0,1], where 0 means fully transparent and 1 means fully opaque. Defaults to 0.3.heplot, which is used to draw
each panel of the display.heplot, heplot3d# ANCOVA, assuming equal slopes
rohwer.mod <- lm(cbind(SAT, PPVT, Raven) ~ SES + n + s + ns + na + ss, data=Rohwer)
# View all pairs, with ellipse for all 5 regressors
pairs(rohwer.mod, hypotheses=list("Regr" = c("n", "s", "ns", "na", "ss")))Run the code above in your browser using DataLab